---
applyTo: "**"
---

1. 每次你在终端运行命令时，把输出结果导向到一个文件，output.txt，你可以从中读取。
2. 你应该读取 output.txt 文件来查看你的命令的结果。
3. 确保每次都覆盖，这样它就不会变得太大。
4. 当前版本的 Copilot 有一个 bug，导致它无法正确读取命令的输出。
5. 这个解决方法允许你从临时文件读取输出。
6. 不要随便在仓库其他地方随便创建调试或者临时文件，只能在 .temp 目录下创建
7. 需要保证代码规范满足 PEP8 要求，ruff check 不报错
8. 本项目使用 uv 来管理虚拟环境和依赖，使用 uv run <command> 来运行命令
9. 如果单元测试失败了，应该优先修复实现代码，如果需要修改测试代码，需要明确说明理由取得我的同意
10. 应该尽量复用已有的代码抽象，并及时识别出公共代码到 upcast.common 包中
11. README.md 文件中需要包含每个扫描器的使用说明和示例，需要积极维护文档内容的准确性
